@@ -7,10 +7,10 @@ mysql_vs_pandas = {
     "int": "int",
     "timestamp": "datetime64",
     "tinyint": "int",
+    "smallint": "int",
     "varchar": "str"
 }
 
-
 mysql_vs_spark = {
     "bigint": "integer",
     "date": "timestamp",
@@ -18,5 +18,6 @@ mysql_vs_spark = {
     "int": "integer",
     "timestamp": "timestamp",
     "tinyint": "integer",
+    "smallint": "integer",
     "varchar": "string"
-}
\ No newline at end of file
+}
